import {
  select,
  create,
  scaleBand,
  range,
  scaleLinear,
  extent,
  autoType,
  csv,
} from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;

const margin = {
  top: 70,
  right: 0,
  bottom: 30,
  left: 40,
};

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(
    'alphabet.csv',
    autoType
  );


  const x = d3
    .scaleBand()
    .domain(data.map((d) => d.letter))
    .rangeRound([
      margin.left,
      width - margin.right,
    ])
    .padding(0.1);

  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.frequency)])
    .range([height - margin.bottom, margin.top]);

  console.log(y.domain());
  const yTitle = (g) =>
    g
      .append('text')
      .attr('font-family', 'sans-serif')
      .attr('font-size', 10)
      .attr('y', 50)
      .text('↑ Frequency');

  const yAxis = (g) =>
    g 
  		.attr('transform', `translate(${margin.left}, 0)`)
      .call(d3.axisLeft(y).ticks(null,'%'))
  

  const xAxis = (g) =>{
  g
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`
      )
      .call(d3.axisBottom(x).tickSizeOuter(0));
  }
    

  svg.append('g').call(xAxis);

  svg.append('g').call(yAxis);

  svg.call(yTitle);

  svg
    .append('g')
    .attr('fill', 'steelblue')
    .selectAll('rect')
    .data(data)
    .join('rect')
    .attr('x', (d) => x(d.letter))
    .attr('y', (d) => y(d.frequency))
    .attr('height', (d) => y(0) - y(d.frequency))
    .attr('width', x.bandwidth());
  
};

main()